@@ -449,7 +449,7 @@ EXECUTE 'ALTER FUNCTION  st_tri(
 	customextent raster,
 	pixeltype text ,	interpolate_nodata boolean  ) SET search_path=' || quote_ident(param_postgis_schema) || ',pg_catalog;';
 EXECUTE 'ALTER FUNCTION  st_bandisnodata(rast raster, forceChecking boolean ) SET search_path=' || quote_ident(param_postgis_schema) || ',pg_catalog;';
-EXECUTE 'ALTER FUNCTION  st_bandmetadata(
+EXECUTE 'ALTER FUNCTION  ST_BandMetaData(
 	rast raster,
 	band int ,
 	OUT pixeltype text,
@@ -459,7 +459,7 @@ EXECUTE 'ALTER FUNCTION  st_bandmetadata(
  ) SET search_path=' || quote_ident(param_postgis_schema) || ',pg_catalog;';
 EXECUTE 'ALTER FUNCTION  st_value(rast raster, x integer, y integer, exclude_nodata_value boolean  ) SET search_path=' || quote_ident(param_postgis_schema) || ',pg_catalog;';
 EXECUTE 'ALTER FUNCTION  st_value(rast raster, band integer, pt geometry, exclude_nodata_value boolean  ) SET search_path=' || quote_ident(param_postgis_schema) || ',pg_catalog;';
-EXECUTE 'ALTER FUNCTION  st_value(rast raster, pt geometry, exclude_nodata_value boolean  ) SET search_path=' || quote_ident(param_postgis_schema) || ',pg_catalog;';
+EXECUTE 'ALTER FUNCTION  ST_Value(rast raster, pt geometry, exclude_nodata_value boolean  ) SET search_path=' || quote_ident(param_postgis_schema) || ',pg_catalog;';
 EXECUTE 'ALTER FUNCTION  st_pixelofvalue(
 	rast raster,
 	search double precision[],
@@ -586,7 +586,7 @@ EXECUTE 'ALTER FUNCTION  st_samealignment(
 	ulx2 double precision, uly2 double precision, scalex2 double precision, scaley2 double precision, skewx2 double precision, skewy2 double precision
  ) SET search_path=' || quote_ident(param_postgis_schema) || ',pg_catalog;';
 EXECUTE 'ALTER FUNCTION  _st_samealignment_transfn(agg agg_samealignment, rast raster ) SET search_path=' || quote_ident(param_postgis_schema) || ',pg_catalog;';
-EXECUTE 'ALTER FUNCTION  _st_samealignment_finalfn(agg agg_samealignment ) SET search_path=' || quote_ident(param_postgis_schema) || ',pg_catalog;';
+EXECUTE 'ALTER FUNCTION  _ST_samealignment_finalfn(agg agg_samealignment ) SET search_path=' || quote_ident(param_postgis_schema) || ',pg_catalog;';
 EXECUTE 'ALTER FUNCTION  st_iscoveragetile(rast raster, coverage raster, tilewidth integer, tileheight integer ) SET search_path=' || quote_ident(param_postgis_schema) || ',pg_catalog;';
 EXECUTE 'ALTER FUNCTION  _st_intersects(geom geometry, rast raster, nband integer  ) SET search_path=' || quote_ident(param_postgis_schema) || ',pg_catalog;';
 EXECUTE 'ALTER FUNCTION  st_intersection(geomin geometry, rast raster, band integer  ) SET search_path=' || quote_ident(param_postgis_schema) || ',pg_catalog;';
